// StrTok.h: CStrTok NX̃C^[tFCX
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_STRTOK_H__15123621_ECD2_11D5_8C76_444553540000__INCLUDED_)
#define AFX_STRTOK_H__15123621_ECD2_11D5_8C76_444553540000__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class CStrTok  
{
public:
	const char* Tokenize(char *in, char *demilitar);
	CStrTok();
	virtual ~CStrTok();

private:
	char* m_pStart;
};

#endif // !defined(AFX_STRTOK_H__15123621_ECD2_11D5_8C76_444553540000__INCLUDED_)
